# django-gmailapi-json-backend
Email backend for Django which sends email via the Gmail API through a JSON credential

## Requirements
Python 3.9+

## Installation
Python DHL API is available through pip. To easily install or upgrade it, do
```
pip install --upgrade django-gmailapi-json-backend
```